aboutsummaryrefslogtreecommitdiff
path: root/engines/agi/cycle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/agi/cycle.cpp')
-rw-r--r--engines/agi/cycle.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/engines/agi/cycle.cpp b/engines/agi/cycle.cpp
index 3d29f45ea5..53bebf1b40 100644
--- a/engines/agi/cycle.cpp
+++ b/engines/agi/cycle.cpp
@@ -115,7 +115,7 @@ void AgiEngine::interpretCycle() {
oldSound = getflag(fSoundOn);
_game.exitAllLogics = false;
- while (runLogic(0) == 0 && !quit()) {
+ while (runLogic(0) == 0 && !shouldQuit()) {
_game.vars[vWordNotFound] = 0;
_game.vars[vBorderTouchObj] = 0;
_game.vars[vBorderCode] = 0;
@@ -352,16 +352,16 @@ int AgiEngine::playGame() {
_game.vars[vKey] = 0;
}
// FIXME: This has been broken with the merge of the RTL GSoC project. quit() returns a boolean, and we're trying to
// check it against 0xff, which is never going to be true
- //if (quit() == 0xff)
+ //if (shouldQuit() == 0xff)
// ec = errRestartGame;
if (shouldPerformAutoSave(_lastSaveTime)) {
saveGame(getSavegameFilename(0), "Autosave");
}
- } while (quit() == 0);
+ } while (shouldQuit() == 0);
_sound->stopSound();
@@ -352,16 +352,16 @@ int AgiEngine::playGame() {
_game.vars[vKey] = 0;
}
- // FIXME: This has been broken with the merge of the RTL GSoC project. quit() returns a boolean, and we're trying to
+ // FIXME: This has been broken with the merge of the RTL GSoC project. shouldQuit() returns a boolean, and we're trying to
// check it against 0xff, which is never going to be true